@@ -1,5 +1,5 @@
-#  tests for pot-0.8.1-py39h2e25243_0 (this is a generated file);
-print('===== testing package: pot-0.8.1-py39h2e25243_0 =====');
+#  tests for pot-0.8.1.0-py39h2e25243_0 (this is a generated file);
+print('===== testing package: pot-0.8.1.0-py39h2e25243_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import numpy as np
@@ -7,7 +7,7 @@ import ot
 
 n = 5
 a, b = np.random.dirichlet([1] * n, size=2)
-M = ot.dist(np.random.randn(n, 5))
+M = ot.dist(np.random.randn(n, 5), metric='cityblock')
 
 W = ot.emd2(a, b, M)
 W_reg = ot.sinkhorn2(a, b, M, .1)
@@ -16,7 +16,7 @@ T = ot.emd(a, b, M)
 T_reg = ot.sinkhorn(a, b, M, .1)
 #  --- run_test.py (end) ---
 
-print('===== pot-0.8.1-py39h2e25243_0 OK =====');
+print('===== pot-0.8.1.0-py39h2e25243_0 OK =====');
 print("import: 'ot'")
 import ot
 
